@@ -564,11 +564,11 @@ initPDFCrack(const EncData *e, const uint8_t *upw, const bool user,
     }
   }
 
-  if(perm || permutation)
+  permutation = (perm || permutation);
+  if(permutation)
     permutate = do_permutate;
   else
     permutate = no_permutate;
-  
 
   initPasswords(pm, file, wl, cs, minPw, maxPw);
   return true;
